# How to contribute

This code repository is part of Project Syn and the contribution guide at
https://syn.tools/syn/about/contribution_guide.html does apply.

Submit Pull Requests at {{ cookiecutter.github_url }}/pulls.
